==> hermes-2.3.4-b05815b7.tar.gz: hermes-2.3.4-b05815b7/spec/models/required_documents_spec.rb <==
require 'rails_helper'
require 'vcr_config'

RSpec.describe Hermes::RequiredDocument, type: :model do
  let!(:user1) {create(:user)}
  let!(:user2) {create(:user)}
  let!(:applicant1) {
    create(
      :applicant,
      user: user1,
      monthly_charges: {"PAV" => 200},
      nationality: "1",
      user_id: user1.id,
      first_name: "robin",
      last_name: "caramaschi",
      birth_date: Date.current,
    )
  }
  
  it 'has a valid factory' do
    expect(FactoryBot.build(:housing_request_folder)).to be_valid
  end
  
  
  let!(:housing_request1) do
    create(
      :housing_request,
      is_active: true,
      main_applicant: applicant1,
      user_id: user1.id
    )
  end
  let!(:nud1) do
    create(
      :nud,
      housing_request: housing_request1,
      department: '12',
      creation_date: '2016-23-14T14:53:22',
      unique_number: "A1253EF84F3"
    )
  end
  describe "les droits sont transmis" do
    it "is good " do
      hrf = housing_request1.reload.housing_request_folder
      required_document = housing_request1.reload.housing_request_folder.required_documents[0]
      expect(housing_request1.user_id).to eq(user1.id)
      expect(hrf.user_id).to eq(user1.id)
      expect(required_document.user_id).to eq(user1.id)
    end
  end
  describe "upload file create it in sne" do
    
    before :each do
      hrf = housing_request1.reload.housing_request_folder
      required_document = housing_request1.reload.housing_request_folder.required_documents[0]
      file = File.open([Hermes::Engine.root, %w[spec xml_bouchon carte-identite.jpg]].flatten.join('/'))
      blob = file.read
      required_document.set_blobs([{filename: "carte-identite-recto.jpg", blob: blob}, {filename: "minion.jpg", blob: blob}])
      required_document.save
    end
    it "status are modified correctly" do
      hrf = housing_request1.reload.housing_request_folder
      hrf.reload
      expect(housing_request1.reload.request_status).to eq("INCOMPLETE")
      hrf.start_treatment
      hrf.save
      hrf.reload
      required_document = housing_request1.reload.housing_request_folder.required_documents[0]
      required_document.status = "Pièce validée"
      required_document.save
      expect(housing_request1.reload.request_status).to eq("ELIGIBLE")
    end
    
    it "go found the goods documents in the sne" do
      expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(2)
      
      rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
      res = []
      
      doc = Doc.find(rd.doc_id)
      File.open([Hermes::Engine.root, %w[spec xml_bouchon], "0retourFile.pdf"].flatten.join('/').to_s, 'wb') do |f|
        f.write doc.file.data
      end
      res.push({
                 filename: doc.title,
                 url: doc.file_md5 && "BASEURL/send/#{doc.file_md5}/#{doc.clean_name}"
               })
      
      
      expect(res.length).to eq(1)
      expect(res[0][:filename]).not_to be(nil)
      # expect(rd.reload.last_xml_validation_report).to eq("[]")
      # expect(rd.reload.sne_piece_id).to eq("16768")
      VCR.use_cassette("send_file_to_ged", :match_requests_on => [:method, :uri, :path]) do
        document = Doc.find(rd.doc_id)
        responses = rd.post_to_ged(document)
        expect(responses["data"]["id"]).not_to be(nil)
        data = responses["data"]
        rd.ged_doc_id = data["id"]
        rd.file_url = data["attributes"]["file_url"]
        VCR.use_cassette("read_file_to_ged", :match_requests_on => [:method, :uri, :path]) do
          expect(rd.get_data_from_ged("5e5cd6b677d81d6356ee7edb")["data"]["attributes"]["pages_urls"]).not_to be(nil)
        end
        VCR.use_cassette("delete_file_to_ged", :match_requests_on => [:method, :uri, :path]) do
          #expect(rd.delete_to_ged(rd.ged_doc_id )).to eq("204 No Content")
        end
      end
    end
  end
  describe "kyc_test" do
    describe "wrong_document" do
      before :each do
        required_document = housing_request1.reload.housing_request_folder.required_documents[0]
        file = File.open([Hermes::Engine.root, %w[spec xml_bouchon minion.jpg]].flatten.join('/'))
        blob = file.read
        required_document.set_blobs([{filename: "minion.jpg", blob: blob}, {filename: "minion.jpg", blob: blob}])
        required_document.save
      end
      it "status are modified correctly" do
        
        required_document = housing_request1.reload.housing_request_folder.required_documents[0]
        required_document.start_treatment("wrong_document")
        expect(required_document.reload.status).to eq("Pièce invalide")
        expect(required_document.reload.validation_errors).to eq([{"message"=>"No MRZ found", "status"=>"KO", "status_code"=>400}])
      end
    end
    describe "identity_recto" do
      before :each do
        required_document = housing_request1.reload.housing_request_folder.required_documents[0]
        file = File.open([Hermes::Engine.root, %w[spec xml_bouchon carte-identite.jpg]].flatten.join('/'))
        blob = file.read
        required_document.set_blobs([{filename: "carte-identite-recto.jpg", blob: blob}])
        required_document.save
      end
      it "status are modified correctly" do
        
        required_document = housing_request1.reload.housing_request_folder.required_documents[0]
        required_document.start_treatment("identity_recto")
        expect(required_document.reload.validation_errors.length).to eq(5)
       # ap required_document.reload.metas
      end
    end 
    describe "sejour" do
      before :each do
        applicant1.nationality = "3"
        applicant1.save
        required_document = housing_request1.reload.housing_request_folder.required_documents[1]
       
        file = File.open([Hermes::Engine.root, %w[spec xml_bouchon sejour.jpg]].flatten.join('/'))
        blob = file.read
        required_document.set_blobs([{filename: "sejour.jpg", blob: blob}])
        required_document.save
      end
      it "status are modified correctly" do
        
        required_document = housing_request1.reload.housing_request_folder.required_documents[1]
        required_document.start_treatment("titresejour")
        expect(required_document.reload.validation_errors.length).to eq(4)
       # ap required_document.reload.metas
      end
    end
    describe "passportspain" do
      before :each do
        applicant1.nationality = "2"
        applicant1.save
        required_document = housing_request1.reload.housing_request_folder.required_documents[1]
    
        file = File.open([Hermes::Engine.root, %w[spec xml_bouchon passportspain.jpg]].flatten.join('/'))
        blob = file.read
        required_document.set_blobs([{filename: "passportspain.jpg", blob: blob}])
        required_document.save
      end
      it "status are modified correctly" do
    
        required_document = housing_request1.reload.housing_request_folder.required_documents[1]
        required_document.start_treatment("passportspain")
        expect(required_document.reload.validation_errors.length).to eq(4)
        ap required_document.reload.metas
      end
    end
    describe "identity_rectoverso" do
      before :each do
        required_document = housing_request1.reload.housing_request_folder.required_documents[0]
        file = File.open([Hermes::Engine.root, %w[spec xml_bouchon recto_ci.png]].flatten.join('/'))
        blob = file.read
        file = File.open([Hermes::Engine.root, %w[spec xml_bouchon verso_ci.png]].flatten.join('/'))
        blob2 = file.read
        required_document.set_blobs([{filename: "carte-identite-recto.png", blob: blob},
                                     {filename: "carte-identite-verso.png", blob: blob2}])
        required_document.save
      end
      it "status are modified correctly" do
    
        required_document = housing_request1.reload.housing_request_folder.required_documents[0]
        required_document.start_treatment("identity_recto_verso")
        expect(required_document.reload.validation_errors.length).to eq(7)
        # ap required_document.reload.metas
      end
    end
    describe "salaire" do
      before :each do
        applicant1.nationality = nil
        applicant1.monthly_incomes = {"SAL" => 2000}
        applicant1.work_contract_type = "CDI"
        applicant1.save
        required_document = housing_request1.reload.housing_request_folder.required_documents[1]
        file = File.open([Hermes::Engine.root, %w[spec xml_bouchon salaire.pdf]].flatten.join('/'))
        blob = file.read
       
        required_document.set_blobs([{filename: "salaire.pdf", blob: blob}])
        required_document.save
      end
      it "status are modified correctly" do
    
        required_document = housing_request1.reload.housing_request_folder.required_documents[1]
        required_document.start_treatment("salaire")
        expect(required_document.reload.validation_errors.length).to eq(1)
      end
    end
=begin
    describe "impots" do
      before :each do
        applicant1.nationality = nil
        applicant1.amount_year_minus_two = 4000
        applicant1.save
        required_document = housing_request1.reload.housing_request_folder.required_documents[1]
        file = File.open([Hermes::Engine.root, %w[spec xml_bouchon impo6.pdf]].flatten.join('/'))
        blob = file.read
       
        required_document.set_blobs([{filename: "impo6.pdf", blob: blob}])
        required_document.save
      end
      it "status are modified correctly" do
    
        required_document = housing_request1.reload.housing_request_folder.required_documents[1]
        required_document.start_treatment("impo6.pdf")
        expect(required_document.reload.validation_errors.length).to eq(0)
        ap required_document.reload.metas
      end
    end
=end
  end
  describe "upload file edit it in sne" do
    
    before :each do
      path = [Hermes::Engine.root, %w[spec xml_bouchon], "0_blob_bouchon"].flatten.join('/').to_s
      pn = Pathname.new(path)
      return {err: 'unknown file'} unless pn.exist?
      blob_bouchon = File.read(pn)
      required_document = housing_request1.reload.housing_request_folder.required_documents[0]
      required_document.set_blobs([{filename: "superPad1.pdf", blob: blob_bouchon}])
      required_document.save
      
      required_document.reload
      return {err: 'unknown file'} unless pn.exist?
      required_document = housing_request1.reload.housing_request_folder.required_documents[0]
      
      required_document.set_blobs([{filename: "superPadUpdate.pdf", blob: blob_bouchon}])
      required_document.save
    end
    
    it "go found the goods documents in the sne" do
      expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(2)
      rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
      res = []
      
      doc = Doc.find(rd.doc_id)
      res.push({
                 filename: doc.title,
                 url: doc.file_md5 && "BASEURL/send/#{doc.file_md5}/#{doc.clean_name}"
               })
      
      
      expect(res.length).to eq(1)
      expect(res[0][:filename]).not_to be(nil)
      #expect(rd.reload.last_xml_validation_report).to eq("[]")
    end
  end
  
  describe "delete file delete it in sne" do
    
    before :each do
      path = [Hermes::Engine.root, %w[spec xml_bouchon], "0_blob_bouchon"].flatten.join('/').to_s
      pn = Pathname.new(path)
      return {err: 'unknown file'} unless pn.exist?
      blob_bouchon = File.read(pn)
      required_document = housing_request1.reload.housing_request_folder.required_documents[0]
      required_document.set_blobs([{filename: "superPad1.pdf", blob: blob_bouchon}])
      required_document.save
      
      required_document.reload
      required_document.destroy
    end
    
    it "go found the goods documents in the sne" do
      expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(2)
      rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
      expect(rd).to eq(nil)
    end
  end
  
  describe "status" do
    describe "status initialisation" do
      it "has status piece manquantes" do
        expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(2)
        rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
        expect(rd.status).to eq("Pièce manquante")
        expect(housing_request1.reload.housing_request_folder.application_status).to eq("Dossier incomplet")
        expect(housing_request1.reload.housing_request_folder.consultation_status).to eq("Dossier incomplet")
      end
    end
    describe "ajout de piece" do
      before :each do
        required_document = housing_request1.reload.housing_request_folder.required_documents[0]
        file = File.open([Hermes::Engine.root, %w[spec xml_bouchon minion.jpg]].flatten.join('/'))
        blob = file.read
        required_document.set_blobs([{filename: "minion.jpg", blob: blob}, {filename: "minion.jpg", blob: blob}])
        required_document.save
      end
      it "has status kyc en cours" do
        expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(2)
        rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
        #  expect(rd.status).to eq("Contrôle en cours")
        #  expect(housing_request1.reload.housing_request_folder.application_status).to eq("Dossier complet en cours de traitement")
        #  expect(housing_request1.reload.housing_request_folder.consultation_status).to eq("Dossier complet en cours de traitement")
      end
    end
    describe "ajout de piece validé kyc" do
      before :each do
        required_document = housing_request1.reload.housing_request_folder.required_documents[0]
        file = File.open([Hermes::Engine.root, %w[spec xml_bouchon minion.jpg]].flatten.join('/'))
        blob = file.read
        required_document.set_blobs([{filename: "minion.jpg", blob: blob}, {filename: "minion.jpg", blob: blob}])
        required_document.save
        required_document.reload
        required_document.validation_errors = []
        required_document.validity_limit = DateTime.current + 3.months
        
        required_document.save
      end
      it "has status kyc en cours" do
        expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(2)
        rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
        expect(rd.status).to eq("A contrôler")
        expect(housing_request1.reload.housing_request_folder.nud_status).to eq("Dossier validé")
        expect(housing_request1.reload.request_status).to eq("ELIGIBLE")
        expect(housing_request1.reload.housing_request_folder.application_status).to eq("Dossier incomplet")
        expect(housing_request1.reload.housing_request_folder.consultation_status).to eq("Dossier validé")
        expect(housing_request1.reload.housing_request_folder.application_status).to eq("Dossier incomplet")
        #  expect(housing_request1.request_status).to eq("COMPLETE")
      end
    end
    describe "ajout de piece invalidé kyc" do
      before :each do
        required_document = housing_request1.reload.housing_request_folder.required_documents[0]
        file = File.open([Hermes::Engine.root, %w[spec xml_bouchon minion.jpg]].flatten.join('/'))
        blob = file.read
        required_document.set_blobs([{filename: "minion.jpg", blob: blob}, {filename: "minion.jpg", blob: blob}])
        required_document.save
        required_document.reload
        required_document.validation_errors = [{ereeur: "zefsfsfs"}]
        required_document.save
      end
      it "has status kyc en cours" do
        expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(2)
        rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
        # expect(rd.status).to eq("Pièce invalide")
        # expect(housing_request1.reload.housing_request_folder.application_status).to eq("Erreurs de validation dans les pieces fournies")
        # expect(housing_request1.reload.housing_request_folder.consultation_status).to eq("Erreurs de validation dans les pieces fournies")
      end
    end
    describe "ajout de piece start treatment" do
      before :each do
        required_document = housing_request1.reload.housing_request_folder.required_documents[0]
        file = File.open([Hermes::Engine.root, %w[spec xml_bouchon minion.jpg]].flatten.join('/'))
        blob = file.read
        required_document.set_blobs([{filename: "minion.jpg", blob: blob}, {filename: "minion.jpg", blob: blob}])
        required_document.save
        required_document.reload
        
        
        required_document.start_treatment
        required_document.status = "Pièce validée"
        required_document.save
      end
      it "has status kyc en cours" do
        expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(2)
        rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
        expect(rd.status).to eq("Pièce validée")
        expect(housing_request1.reload.housing_request_folder.nud_status).to eq("Dossier validé")
        expect(housing_request1.reload.request_status).to eq("ELIGIBLE")
        expect(housing_request1.reload.housing_request_folder.application_status).to eq("Dossier incomplet")
        expect(housing_request1.reload.housing_request_folder.consultation_status).to eq("Dossier validé")
        expect(housing_request1.reload.housing_request_folder.application_status).to eq("Dossier incomplet")
        #  expect(housing_request1.request_status).to eq("COMPLETE")
      end
    end
    describe "ajout de piece invalidé kyc" do
      before :each do
        required_document = housing_request1.reload.housing_request_folder.required_documents[0]
        file = File.open([Hermes::Engine.root, %w[spec xml_bouchon minion.jpg]].flatten.join('/'))
        blob = file.read
        required_document.set_blobs([{filename: "minion.jpg", blob: blob}, {filename: "minion.jpg", blob: blob}])
        required_document.save
        required_document.reload
        required_document.validation_errors = [{ereeur: "zefsfsfs"}]
        required_document.save
      end
      it "has status kyc en cours" do
        expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(2)
        rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
        # expect(rd.status).to eq("Pièce invalide")
        # expect(housing_request1.reload.housing_request_folder.application_status).to eq("Erreurs de validation dans les pieces fournies")
        # expect(housing_request1.reload.housing_request_folder.consultation_status).to eq("Erreurs de validation dans les pieces fournies")
      end
    end
    describe "multi piece" do
      before :each do
        housing_request1.unborn_children = [{
                                              "anticipated_birth" => (Time.current + 10.days).to_s,
                                            }]
        housing_request1.save
        mapp = housing_request1.main_applicant
        mapp.amount_year_minus_two = 2000
        mapp.save
        required_document = housing_request1.reload.housing_request_folder.required_documents[0]
        file = File.open([Hermes::Engine.root, %w[spec xml_bouchon minion.jpg]].flatten.join('/'))
        blob = file.read
        required_document.set_blobs([{filename: "minion.jpg", blob: blob}, {filename: "minion.jpg", blob: blob}])
        required_document.save
      end
      it "has status kyc en cours" do
        expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(4)
        rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
        expect(rd.status).to eq("Prêt pour traitement")
        
        expect(housing_request1.reload.housing_request_folder.nud_status).to eq("Dossier complet prêt pour traitement")
        expect(housing_request1.reload.housing_request_folder.application_status).to eq("Dossier incomplet")
        expect(housing_request1.reload.housing_request_folder.consultation_status).to eq("Dossier incomplet")
        housing_request1.reload.housing_request_folder.start_treatment
        expect(housing_request1.reload.housing_request_folder.nud_status).to eq("Erreurs de validation dans les pieces fournies")
        rd.status = "Pièce validée"
        rd.save
        expect(housing_request1.reload.housing_request_folder.nud_status).to eq("Dossier validé")
        expect(housing_request1.reload.housing_request_folder.application_status).to eq("Dossier incomplet")
        expect(housing_request1.reload.housing_request_folder.consultation_status).to eq("Dossier incomplet")
        expect(housing_request1.request_status).to eq("EN ATTENTE DE PIECES")
      end
    end
  end
end

==> hermes-2.3.4-2b292931.tar.gz: hermes-2.3.4-2b292931/spec/models/required_documents_spec.rb <==
require 'rails_helper'
require 'vcr_config'

RSpec.describe Hermes::RequiredDocument, type: :model do
  let!(:user1) {create(:user)}
  let!(:user2) {create(:user)}
  let!(:applicant1) {
    create(
      :applicant,
      user: user1,
      monthly_charges: {},
      nationality: "1",
      user_id: user1.id,
    )
  }
  
  it 'has a valid factory' do
    expect(FactoryBot.build(:housing_request_folder)).to be_valid
  end
  
  
  let!(:housing_request1) do
    create(
      :housing_request,
      is_active: true,
      main_applicant: applicant1,
      user_id: user1.id,
    )
  end
  let!(:nud1) do
    create(
      :nud,
      housing_request: housing_request1,
      department: '12',
      creation_date: '2016-23-14T14:53:22',
      unique_number: "A1253EF84F3"
    )
  end
  describe "les droits sont transmis" do
    it "is good " do
      hrf = housing_request1.reload.housing_request_folder
      required_document = housing_request1.reload.housing_request_folder.required_documents[0]
      expect(housing_request1.user_id).to eq(user1.id)
      expect(hrf.user_id).to eq(user1.id)
      expect(required_document.user_id).to eq(user1.id)
    end
  end
  describe "upload file create it in sne" do
    
    before :each do
      hrf = housing_request1.reload.housing_request_folder
  
      required_document = housing_request1.reload.housing_request_folder.required_documents[0]
      file = File.open([Hermes::Engine.root, %w[lib hermes tools minion.jpg]].flatten.join('/'))
      blob = file.read
      required_document.set_blobs([{filename: "minion.jpg", blob: blob}, {filename: "minion.jpg", blob: blob}])
      required_document.save
    end
    it "status are modified correctly" do
      hrf = housing_request1.reload.housing_request_folder
      ap hrf.reload
      expect(housing_request1.reload.request_status).to eq("INCOMPLETE")
      hrf.start_treatment
      hrf.save
      ap hrf.reload
      expect(housing_request1.reload.request_status).to eq("COMPLETE")
    end
    it "go found the goods documents in the sne" do
      expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(1)
 
      rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
      res = []
     
        doc = Doc.find(rd.doc_id)
        File.open([Hermes::Engine.root, %w[spec xml_bouchon], "0retourFile.pdf"].flatten.join('/').to_s, 'wb') do |f|
          f.write doc.file.data
        end
        res.push({
                   filename: doc.title,
                   url: doc.file_md5 && "BASEURL/send/#{doc.file_md5}/#{doc.clean_name}"
                 })
    
      
      expect(res.length).to eq(1)
      expect(res[0][:filename]).not_to be(nil)
     # expect(rd.reload.last_xml_validation_report).to eq("[]")
     # expect(rd.reload.sne_piece_id).to eq("16768")
      VCR.use_cassette("send_file_to_ged", :match_requests_on => [:method, :uri, :path]) do
        document = Doc.find(rd.doc_id)
        responses = rd.post_to_ged(document)
        expect(responses["data"]["id"]).not_to be(nil)
        data = responses["data"]
        rd.ged_doc_id = data["id"]
        rd.file_url = data["attributes"]["file_url"]
        VCR.use_cassette("read_file_to_ged", :match_requests_on => [:method, :uri, :path]) do
         expect(rd.get_data_from_ged("5e5cd6b677d81d6356ee7edb")["data"]["attributes"]["pages_urls"]).not_to be(nil)
        end
        VCR.use_cassette("delete_file_to_ged", :match_requests_on => [:method, :uri, :path]) do
       #expect(rd.delete_to_ged(rd.ged_doc_id )).to eq("204 No Content")
          end
      end
    end
  end
  describe "upload file edit it in sne" do
    
    before :each do
      path = [Hermes::Engine.root, %w[spec xml_bouchon], "0_blob_bouchon"].flatten.join('/').to_s
      pn = Pathname.new(path)
      return {err: 'unknown file'} unless pn.exist?
      blob_bouchon = File.read(pn)
      required_document = housing_request1.reload.housing_request_folder.required_documents[0]
      required_document.set_blobs([{filename: "superPad1.pdf", blob: blob_bouchon}])
      required_document.save
      
      required_document.reload
      return {err: 'unknown file'} unless pn.exist?
      required_document = housing_request1.reload.housing_request_folder.required_documents[0]
  
      required_document.set_blobs([{filename: "superPadUpdate.pdf", blob: blob_bouchon}])
      required_document.save
    end
    
    it "go found the goods documents in the sne" do
      expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(1)
      rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
      res = []
      
        doc = Doc.find(rd.doc_id)
        res.push({
                   filename: doc.title,
                   url: doc.file_md5 && "BASEURL/send/#{doc.file_md5}/#{doc.clean_name}"
                 })
    
      
      expect(res.length).to eq(1)
      expect(res[0][:filename]).not_to be(nil)
      #expect(rd.reload.last_xml_validation_report).to eq("[]")
    end
  end
  
  describe "delete file delete it in sne" do
    
    before :each do
      path = [Hermes::Engine.root, %w[spec xml_bouchon], "0_blob_bouchon"].flatten.join('/').to_s
      pn = Pathname.new(path)
      return {err: 'unknown file'} unless pn.exist?
      blob_bouchon = File.read(pn)
      required_document = housing_request1.reload.housing_request_folder.required_documents[0]
      required_document.set_blobs([{filename: "superPad1.pdf", blob: blob_bouchon}])
      required_document.save
      
      required_document.reload
      required_document.destroy
    end
    
    it "go found the goods documents in the sne" do
      expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(1)
      rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
      expect(rd).to eq(nil)
    end
  end
  
  describe "status" do
    describe "status initialisation" do
      it "has status piece manquantes" do
        expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(1)
        rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
        expect(rd.status).to eq("Pièce manquante")
        expect(housing_request1.reload.housing_request_folder.application_status).to eq("Dossier incomplet")
        expect(housing_request1.reload.housing_request_folder.consultation_status).to eq("Dossier incomplet")
      end
    end
    describe "ajout de piece" do
      before :each do
        required_document = housing_request1.reload.housing_request_folder.required_documents[0]
        file = File.open([Hermes::Engine.root, %w[lib hermes tools minion.jpg]].flatten.join('/'))
        blob = file.read
        required_document.set_blobs([{filename: "minion.jpg", blob: blob}, {filename: "minion.jpg", blob: blob}])
        required_document.save
      end
      it "has status kyc en cours" do
        expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(1)
        rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
        #  expect(rd.status).to eq("Contrôle en cours")
        #  expect(housing_request1.reload.housing_request_folder.application_status).to eq("Dossier complet en cours de traitement")
        #  expect(housing_request1.reload.housing_request_folder.consultation_status).to eq("Dossier complet en cours de traitement")
      end
    end
    describe "ajout de piece validé kyc" do
      before :each do
        required_document = housing_request1.reload.housing_request_folder.required_documents[0]
        file = File.open([Hermes::Engine.root, %w[lib hermes tools minion.jpg]].flatten.join('/'))
        blob = file.read
        required_document.set_blobs([{filename: "minion.jpg", blob: blob}, {filename: "minion.jpg", blob: blob}])
        required_document.save
        required_document.reload
        required_document.validation_errors = "[]"
        required_document.validity_limit = DateTime.current + 3.months
        
        required_document.save
      end
      it "has status kyc en cours" do
        expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(1)
        rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
        expect(rd.status).to eq("Pièce validée")
        expect(housing_request1.reload.housing_request_folder.application_status).to eq("Dossier validé")
        expect(housing_request1.reload.housing_request_folder.consultation_status).to eq("Dossier validé")
      #  expect(housing_request1.request_status).to eq("COMPLETE")
      end
    end
    describe "ajout de piece invalidé kyc" do
      before :each do
        required_document = housing_request1.reload.housing_request_folder.required_documents[0]
        file = File.open([Hermes::Engine.root, %w[lib hermes tools minion.jpg]].flatten.join('/'))
        blob = file.read
        required_document.set_blobs([{filename: "minion.jpg", blob: blob}, {filename: "minion.jpg", blob: blob}])
        required_document.save
        required_document.reload
        required_document.validation_errors = "[{ereeur : zefsfsfs}]"
        required_document.save
      end
      it "has status kyc en cours" do
        expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(1)
        rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
        # expect(rd.status).to eq("Pièce invalide")
        # expect(housing_request1.reload.housing_request_folder.application_status).to eq("Erreurs de validation dans les pieces fournies")
        # expect(housing_request1.reload.housing_request_folder.consultation_status).to eq("Erreurs de validation dans les pieces fournies")
      end
    end
    describe "multi piece" do
      before :each do
        housing_request1.unborn_children = [{
                                              "anticipated_birth" =>(Time.current + 10.days).to_s,
                                            }]
        housing_request1.save
        required_document = housing_request1.reload.housing_request_folder.required_documents[0]
        file = File.open([Hermes::Engine.root, %w[lib hermes tools minion.jpg]].flatten.join('/'))
        blob = file.read
        required_document.set_blobs([{filename: "minion.jpg", blob: blob}, {filename: "minion.jpg", blob: blob}])
        required_document.save
      end
      it "has status kyc en cours" do
        expect(housing_request1.reload.housing_request_folder.required_document_ids.length).to eq(2)
        rd = Hermes::RequiredDocument.find(housing_request1.reload.housing_request_folder.required_document_ids[0])
        # expect(rd.status).to eq("Contrôle en cours")
        # expect(housing_request1.reload.housing_request_folder.application_status).to eq("Dossier incomplet")
        # expect(housing_request1.reload.housing_request_folder.consultation_status).to eq("Dossier complet en cours de traitement")
      end
    end
  end
end
